﻿$packageName = 'freecommander.xe -Version 2015.685'





Write-Debug ("Starting " + $MyInvocation.MyCommand.Definition)

[string]$packageName = "freecommander.xe -Version 2015.685"
try
{
# We start by retrieving all the app names and uninstall strings from the 64 bit app location (Hey its 2014 and all your OSs are 64 bit arent they? :-))
# This would be the 32 app location if your OS is 32 bit
$uninstallapplist = @(Get-ChildItem HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall |
foreach-object { get-itemproperty $_.PSPath } |
select-object DisplayName, QuietUninstallString |
Where-Object { $_.DisplayName -ne $null -and $_.QuietUninstallString -ne $null })
# Next we add the 32 bit apps - Remove this if your OS is 32 bit only
$uninstallapplist += @(Get-ChildItem HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall |
foreach-object { get-itemproperty $_.PSPath } |
select-object DisplayName, QuietUninstallString |
Where-Object { $_.DisplayName -ne $null -and $_.QuietUninstallString -ne $null })
# Lastly we add apps that are installed as User based rather than machine based
# Sometimes this key doesnt exist so to prevent an error we check to see if it exists first
# As this is user based, this will not pick up apps installed under another userid!!!
if (test-path HKCU:\Software\Microsoft\Windows\CurrentVersion\Uninstall)
{
	$uninstallapplist += @(Get-ChildItem HKCU:\Software\Microsoft\Windows\CurrentVersion\Uninstall |
	ForEach-Object { get-itemproperty $_.PSPath } |
	select-object DisplayName, QuietUninstallString |
	Where-Object { $_.DisplayName -ne $null -and $_.QuietUninstallString -ne $null })
}
# Next we filter the list to retrieve only those programs that we want to uninstall
# Note that we want to specify a wildcard string that will target a specific application correctly (i.e. not multiple matches, unless thats what you want)
# We also want to make the wildcard sort of future proof by omitting any version information (unless you want to target a specific version)
# If you dont know what string to look for just run the above code and add the line "$uninstallapplist | out-gridview" to check all current entries
# I found with version 4 of powershell that the entries were doubling up for some reason - hence the sort unique
$uninstallapplist = $uninstallapplist | Where-Object {
	$_.DisplayName -like "*freecommander*"
} |
sort-object DisplayName -Unique

# Now that we have the list - let's go through each one and uninstall it

foreach ($app in $uninstallapplist)
{
	write-host "Uninstalling $($app.displayname) ...."
	if ($app.QuietUninstallString -like "msiexec.exe*")
	{
		# If the uninstall string starts with msiexec we are going to run it differently
		$app.QuietUninstallString = $app.QuietUninstallString -replace "/I", "/X" # Some developers put a /I instead of a /X so we first change that
		$app.QuietUninstallString = $app.QuietUninstallString -replace "msiexec.exe ", "" # next we get rid of the msiexec program and just keep the arguments
		$app.QuietUninstallString = "$($app.QuietUninstallString) /qn" # we add the /qn for silent uninstalls
		# And the following command uninstalls the program...
		$retcode = (start-process -filepath "msiexec.exe" -ArgumentList "$($app.QuietUninstallString)" -wait -passthru).exitcode
		# If you get a return code of 1603 with an error about a program not being found it probably means that the original source files no longer exist (i.e. where it was installed from)
		# In that case it may very well still uninstall successfully - thats for you to test
	}
	# If the uninstall command is not an msiexec program then we do things differently - Note: I have included the following code but not tested it yet - It should work :-)
	else
	{
		# If the uninstall command itself has double quotes around it because it has spaces in the path, then we have to use the "&" prefix
		if ($app.QuietUninstallString[0] -eq '"') { Invoke-Expression "& $($app.QuietUninstallString)" }
		# Otherwise we just invoke the uninstall string
		else { Invoke-Expression $app.QuietUninstallString }
		# and get the exit code
		$retcode = $LASTEXITCODE
	}
	write-host "$($app.displayname) uninstalled - Return code: $retcode"
}

  Write-ChocolateySuccess $packageName


} catch {
  Write-ChocolateyFailure $packageName $($_.Exception.Message)
  throw
}
